@@ -29,7 +29,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2003  Craig Barratt
+#   Copyright (C) 2001-2009  Craig Barratt
 #
 #   See http://backuppc.sourceforge.net.
 #
@@ -103,19 +103,17 @@ $Conf{UmaskMode} = 027;
 #
 # Examples:
 #     $Conf{WakeupSchedule} = [22.5];         # once per day at 10:30 pm.
-#     $Conf{WakeupSchedule} = [1..23];        # every hour except midnight
 #     $Conf{WakeupSchedule} = [2,4,6,8,10,12,14,16,18,20,22];  # every 2 hours
 #
 # The default value is every hour except midnight.
 #
-# The first entry of $Conf{WakeupSchedule} is when BackupPC_nightly
-# is run.  No other backups can run while BackupPC_nightly is
-# running.  You might want to re-arrange the entries in
-# $Conf{WakeupSchedule} (they don't have to be ascending) so that
-# the first entry is when you want BackupPC_nightly to run
-# (eg: when you don't expect a lot of regular backups to run).
+# The first entry of $Conf{WakeupSchedule} is when BackupPC_nightly is run.
+# You might want to re-arrange the entries in $Conf{WakeupSchedule}
+# (they don't have to be ascending) so that the first entry is when
+# you want BackupPC_nightly to run (eg: when you don't expect a lot
+# of regular backups to run).
 #
-$Conf{WakeupSchedule} = [1..23];
+$Conf{WakeupSchedule} = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23];
 
 #
 # Maximum number of simultaneous backups to run.  If there
@@ -138,7 +136,13 @@ $Conf{MaxUserBackups} = 4;
 # This limit is to make sure BackupPC doesn't fall too far behind in
 # running BackupPC_link commands.
 #
-$Conf{MaxPendingCmds} = 10;
+$Conf{MaxPendingCmds} = 15;
+
+#
+# Nice level at which CmdQueue commands (eg: BackupPC_link and
+# BackupPC_nightly) are run at.
+#
+$Conf{CmdQueueNice} = 10;
 
 #
 # How many BackupPC_nightly processes to run in parallel.
@@ -146,8 +150,9 @@ $Conf{MaxPendingCmds} = 10;
 # Each night, at the first wakeup listed in $Conf{WakeupSchedule},
 # BackupPC_nightly is run.  Its job is to remove unneeded files
 # in the pool, ie: files that only have one link.  To avoid race
-# conditions, BackupPC_nightly runs only when there are no backups
-# running, and no backups will start while it runs.
+# conditions, BackupPC_nightly and BackupPC_link cannot run at
+# the same time.  Starting in v3.0.0, BackupPC_nightly can run
+# concurrently with backups (BackupPC_dump).
 #
 # So to reduce the elapsed time, you might want to increase this
 # setting to run several BackupPC_nightly processes in parallel
@@ -209,6 +214,10 @@ $Conf{DfPath} = '';
 #   $dfPath      path to df ($Conf{DfPath})
 #   $topDir      top-level BackupPC data directory
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{DfCmd} = '$dfPath $topDir';
 
 #
@@ -285,6 +294,14 @@ $Conf{BackupPCUser} = '';
 #                with configure.pl to change InstallDir.
 #   CgiDir     - Apache CGI directory for BackupPC_Admin
 #
+# Note: it is STRONGLY recommended that you don't change the
+# values here.  These are set at installation time and are here
+# for reference and are used during upgrades.
+#
+# Instead of changing TopDir here it is recommended that you use
+# a symbolic link to the new location, or mount the new BackupPC
+# store at the existing $Conf{TopDir} setting.
+#
 $Conf{TopDir}      = '';
 $Conf{ConfDir}     = '';
 $Conf{LogDir}      = '';
@@ -334,6 +351,10 @@ $Conf{PerlModuleLoad}     = undef;
 #                            . ' $serverInitdPath start'
 #                            . ' < /dev/null >& /dev/null';
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{ServerInitdPath} = '';
 $Conf{ServerInitdStartCmd} = '';
 
@@ -696,6 +717,12 @@ $Conf{BackupFilesOnly} = undef;
 # Users report that for smbclient you should specify a directory
 # followed by "/*", eg: "/proc/*", instead of just "/proc".
 #
+# FTP servers are traversed recursively so excluding directories will
+# also exclude its contents.  You can use the wildcard characters "*"
+# and "?" to define files for inclusion and exclusion.  Both
+# attributes $Conf{BackupFilesOnly} and $Conf{BackupFilesExclude} can
+# be defined for the same share.
+#
 # If a hash is used, a special key "*" means it applies to all
 # shares that don't have a specific entry.
 #
@@ -870,6 +897,21 @@ $Conf{XferLogLevel} = 1;
 #
 $Conf{ClientCharset} = '';
 
+#
+# Prior to 3.x no charset conversion was done by BackupPC.  Backups were
+# stored in what ever charset the XferMethod provided - typically utf8
+# for smbclient and the client's locale settings for rsync and tar (eg:
+# cp1252 for rsync on WinXX and perhaps iso-8859-1 with rsync on linux).
+# This setting tells BackupPC the charset that was used to store file
+# names in old backups taken with BackupPC 2.x, so that non-ascii file
+# names in old backups can be viewed and restored.
+#
+$Conf{ClientCharsetLegacy} = 'iso-8859-1';
+
+###########################################################################
+# Samba Configuration
+# (can be overwritten in the per-PC log file)
+###########################################################################
 #
 # Name of the host share that is backed up when using SMB.  This can be a
 # string or an array of strings if there are multiple shares per host.
@@ -929,6 +971,10 @@ $Conf{SmbClientPath} = '';
 #    $X_option        exclude option (if $fileList is an exclude list)
 #    $timeStampFile   start time for incremental dump
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -N -d 1'
             . ' -c tarmode\\ full -Tc$X_option - $fileList';
@@ -939,6 +985,10 @@ $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 #
 # Same variable substitutions are applied as $Conf{SmbClientFullCmd}.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -N -d 1'
 	    . ' -c tarmode\\ full -TcN$X_option $timeStampFile - $fileList';
@@ -953,10 +1003,18 @@ $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 # You should set $Conf{SmbClientRestoreCmd} to undef and the
 # corresponding CGI restore option will be removed.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
             . ' $I_option -U $userName -E -N -d 1'
             . ' -c tarmode\\ full -Tx -';
 
+###########################################################################
+# Tar Configuration
+# (can be overwritten in the per-PC log file)
+###########################################################################
 #
 # Which host directories to backup when using tar transport.  This can be a
 # string or an array of strings if there are multiple directories to
@@ -1023,6 +1081,10 @@ $Conf{TarShareName} = '/';
 #
 # This setting only matters if $Conf{XferMethod} = 'tar'.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{TarClientCmd} = '$sshPath -q -x -n -l root $host'
                     . ' env LC_ALL=C $tarPath -c -v -f - -C $shareName+'
                     . ' --totals';
@@ -1080,6 +1142,10 @@ $Conf{TarIncrArgs} = '--newer=$incrDate+ $fileList+';
 # $Conf{TarClientRestoreCmd} to undef and the corresponding CGI
 # restore option will be removed.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
 		   . ' env LC_ALL=C $tarPath -x -p --numeric-owner --same-owner'
 		   . ' -v -f - -C $shareName+';
@@ -1092,6 +1158,10 @@ $Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
 #
 $Conf{TarClientPath} = '';
 
+###########################################################################
+# Rsync/Rsyncd Configuration
+# (can be overwritten in the per-PC log file)
+###########################################################################
 #
 # Path to rsync executable on the client
 #
@@ -1129,6 +1199,10 @@ $Conf{RsyncClientCmd} = '$sshPath -q -x -l root $host $rsyncPath $argList+';
 #
 # This setting only matters if $Conf{XferMethod} = 'rsync'.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{RsyncClientRestoreCmd} = '$sshPath -q -x -l root $host $rsyncPath $argList+';
 
 #
@@ -1204,16 +1278,6 @@ $Conf{RsyncCsumCacheVerifyProb} = 0.01;
 # Arguments to rsync for backup.  Do not edit the first set unless you
 # have a thorough understanding of how File::RsyncP works.
 #
-# Examples of additional arguments that should work are --exclude/--include,
-# eg:
-#
-#     $Conf{RsyncArgs} = [
-#           # original arguments here
-#           '-v',
-#           '--exclude', '/proc',
-#           '--exclude', '*.tmp',
-#     ];
-#
 $Conf{RsyncArgs} = [
 	    #
 	    # Do not edit these!
@@ -1237,12 +1301,40 @@ $Conf{RsyncArgs} = [
             # to enable checksum caching.
 	    #
 	    #'--checksum-seed=32761',
-
-	    #
-	    # Add additional arguments here
-	    #
 ];
 
+#
+# Additional arguments added to RsyncArgs.  This can be used in
+# conbination with $Conf{RsyncArgs} to allow customization of
+# the rsync arguments on a part-client basis.  The standard
+# arguments go in $Conf{RsyncArgs} and $Conf{RsyncArgsExtra}
+# can be set on a per-client basis.
+#
+# Examples of additional arguments that should work are --exclude/--include,
+# eg:
+#
+#     $Conf{RsyncArgsExtra} = [
+#           '--exclude', '/proc',
+#           '--exclude', '*.tmp',
+#     ];
+#
+# Both $Conf{RsyncArgs} and $Conf{RsyncArgsExtra} are subject
+# to the following variable substitutions:
+#
+#        $client       client name being backed up
+#        $host         host name (could be different from client name if
+#                                 $Conf{ClientNameAlias} is set)
+#        $hostIP       IP address of host
+#        $confDir      configuration directory path
+#
+# This allows settings of the form:
+#
+#     $Conf{RsyncArgsExtra} = [
+#             '--exclude-from=$confDir/pc/$host.exclude',
+#     ];
+#
+$Conf{RsyncArgsExtra} = [];
+
 #
 # Arguments to rsync for restore.  Do not edit the first set unless you
 # have a thorough understanding of how File::RsyncP works.
@@ -1251,6 +1343,17 @@ $Conf{RsyncArgs} = [
 # is read-only), you should set $Conf{RsyncRestoreArgs} to undef and
 # the corresponding CGI restore option will be removed.
 #
+# $Conf{RsyncRestoreArgs} is subject to the following variable
+# substitutions:
+#
+#        $client       client name being backed up
+#        $host         host name (could be different from client name if
+#                                 $Conf{ClientNameAlias} is set)
+#        $hostIP       IP address of host
+#        $confDir      configuration directory path
+#
+# Note: $Conf{RsyncArgsExtra} doesn't apply to $Conf{RsyncRestoreArgs}.
+#
 $Conf{RsyncRestoreArgs} = [
 	    #
 	    # Do not edit these!
@@ -1282,63 +1385,103 @@ $Conf{RsyncRestoreArgs} = [
 	    #
 ];
 
+###########################################################################
+# FTP Configuration
+# (can be overwritten in the per-PC log file)
+##########################################################################
 #
-# Share name to backup.  For $Conf{XferMethod} = "backuppcd" this should
-# be a file system path, eg '/' or '/home'.
+# Which host directories to backup when using FTP.  This can be a
+# string or an array of strings if there are multiple shares per host.
 #
-# This can also be a list of multiple file system paths or modules.
-# (Can it??)
+# This value must be specified in one of two ways: either as a
+# subdirectory of the 'share root' on the server, or as the absolute
+# path of the directory.
 #
-#     $Conf{BackupPCdShareName} = ['/', '/var', '/data', '/boot'];
+# In the following example, if the directory /home/username is the
+# root share of the ftp server with the given username, the following
+# two values will back up the same directory:
 #
-$Conf{BackupPCdShareName} = '/';
+#    $Conf{FtpShareName} = 'www';                # www directory
+#    $Conf{FtpShareName} = '/home/username/www'; # same directory
+#
+# Path resolution is not supported; i.e.; you may not have an ftp
+# share path defined as '../otheruser' or '~/games'.
+#
+#  Multiple shares may also be specified, as with other protocols:
+#
+#    $Conf{FtpShareName} = [ 'www',
+#                            'bin',
+#                            'config' ];
+#
+# Note also that you can also use $Conf{BackupFilesOnly} to specify
+# a specific list of directories to backup.  It's more efficient to
+# use this option instead of $Conf{FtpShareName} since a new tar is
+# run for each entry in $Conf{FtpShareName}.
+#
+# This setting only matters if $Conf{XferMethod} = 'ftp'.
+#
+$Conf{FtpShareName} = '';
 
 #
-# Path to backuppcd executable on the server
+# FTP user name.  This is used to log into the server.
 #
-$Conf{BackupPCdPath} = '';
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
+#
+$Conf{FtpUserName} = '';
 
 #
-# Full command to run backuppcd on the server to backup a given
-# client machine.  The following variables are substituted at
-# run-time (TODO: update this list)
+# FTP user password.  This is used to log into the server.
 #
-#        $host           host name being backed up
-#        $hostIP         host's IP address
-#        $shareName      share name to backup (ie: top-level directory path)
-#        $backuppcdPath  same as $Conf{BackupPCdPath}
-#        $sshPath        same as $Conf{SshPath}
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
 #
-# This setting only matters if $Conf{XferMethod} = 'backuppcd'.
-#
-# Arguments to backupcpd are:
-#
-#   - the host name to backup
-#   - the share name to backup
-#   - the directory where the pool is
-#   - the directory where the last run was (NOT DONE YET)
-#   - a boolean value indicating whether or not the pool is
-#      compressed or not
-#   - the directory where the new run should occur (currently it assumes ".")
-#
-$Conf{BackupPCdCmd} = '$bpcdPath $host $shareName $poolDir XXXX $poolCompress $topDir/pc/$client/new';
+$Conf{FtpPasswd} = '';
 
 #
-# Full command to run backuppcd on the server for restore to a
-# client machine.  The following variables are substituted at
-# run-time (TODO: update this list)
+# Whether passive mode is used.  The correct setting depends upon
+# whether local or remote ports are accessible from the other machine,
+# which is affected by any firewall or routers between the FTP server
+# on the client and the BackupPC server.
 #
-#        $host           host name being backed up
-#        $hostIP         host's IP address
-#        $shareName      share name to backup (ie: top-level directory path)
-#        $backuppcdPath  same as $Conf{BackupPCdPath}
-#        $sshPath        same as $Conf{SshPath}
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
 #
-# This setting only matters if $Conf{XferMethod} = 'backuppcd'.
-#
-$Conf{BackupPCdRestoreCmd} = '$bpcdPath TODO';
+$Conf{FtpPassive} = 1;
 
+#
+# Transfer block size. This sets the size of the amounts of data in
+# each frame. While undefined, this value takes the default value.
+#
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
+#
+$Conf{FtpBlockSize} = 10240;
 
+#
+# The port of the ftp server.  If undefined, 21 is used.
+#
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
+#
+$Conf{FtpPort} = 21;
+
+#
+# Connection timeout for FTP.  When undefined, the default is 120 seconds.
+#
+# This setting is used only if $Conf{XferMethod} = 'ftp'.
+#
+$Conf{FtpTimeout} = 120;
+
+#
+# Behaviour when BackupPC encounters symlinks on the FTP share.
+#
+# Symlinks cannot be restored via FTP, so the desired behaviour will
+# be different depending on the setup of the share. The default for
+# this behavor is 1.  Directory shares with more complicated directory
+# structures should consider other protocols.
+#
+$Conf{FtpFollowSymlinks} = 0;
+
+###########################################################################
+# Archive Configuration
+# (can be overwritten in the per-PC log file)
+###########################################################################
 #
 # Archive Destination
 #
@@ -1404,6 +1547,10 @@ $Conf{ArchiveSplit} = 0;
 #   $archiveloc    The location to put the archive
 #   $parfile       The amount of parity data to create (percentage)
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{ArchiveClientCmd} = '$Installdir/bin/BackupPC_archiveHost'
 	. ' $tarCreatePath $splitpath $parpath $host $backupnumber'
 	. ' $compression $compext $splitsize $archiveloc $parfile *';
@@ -1433,6 +1580,10 @@ $Conf{NmbLookupPath} = '';
 # This command is only used for DHCP hosts: given an IP address, this
 # command should try to find its NetBios name.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{NmbLookupCmd} = '$nmbLookupPath -A $host';
 
 #
@@ -1460,6 +1611,10 @@ $Conf{NmbLookupCmd} = '$nmbLookupPath -A $host';
 # Experiment manually for your site to see what form of nmblookup command
 # works.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{NmbLookupFindHostCmd} = '$nmbLookupPath $host';
 
 #
@@ -1493,6 +1648,10 @@ $Conf{PingPath} = '';
 # exit status (0 even on failure).  Replace with "ping $host 1", which
 # gets the correct exit status but we don't get the round-trip time.
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{PingCmd} = '$pingPath -c 1 $host';
 
 #
@@ -1639,6 +1798,10 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 #        $type         set to "archive"
 #        $cmdType      set to ArchivePreUserCmd or ArchivePostUserCmd
 #
+# Note: all Cmds are executed directly without a shell, so the prog name
+# needs to be a full path and you can't include shell syntax like
+# redirection and pipes; put that in a script if you need it.
+#
 $Conf{DumpPreUserCmd}     = undef;
 $Conf{DumpPostUserCmd}    = undef;
 $Conf{DumpPreShareCmd}    = undef;
@@ -1814,13 +1977,12 @@ $Conf{EMailOutlookBackupSubj} = undef;
 $Conf{EMailOutlookBackupMesg} = undef;
 
 #
-# Additional email headers.  If you change the charset
-# to utf8 then BackupPC_sendEmail will use utf8 for
-# the email body.
+# Additional email headers.  This sets to charset to
+# utf8.
 #
 $Conf{EMailHeaders} = <<EOF;
 MIME-Version: 1.0
-Content-Type: text/plain; charset="iso-8859-1"
+Content-Type: text/plain; charset="utf-8"
 EOF
 
 ###########################################################################
@@ -1864,8 +2026,8 @@ $Conf{CgiURL} = undef;
 #   
 # Language to use.  See lib/BackupPC/Lang for the list of supported
 # languages, which include English (en), French (fr), Spanish (es),
-# German (de), Italian (it), Dutch (nl) and Portuguese Brazillian
-# (pt_br).
+# German (de), Italian (it), Dutch (nl), Polish (pl), Portuguese
+# Brazillian (pt_br) and Chinese (zh_CH).
 #
 # Currently the Language setting applies to the CGI interface and email
 # messages sent to users.  Log files and other text are still in English.
@@ -1897,8 +2059,9 @@ $Conf{CgiUserHomePageCheck} = '';
 $Conf{CgiUserUrlCreate}     = 'mailto:%s';
 
 #
-# Date display format for CGI interface.  True for US-style dates (MM/DD)
-# and zero for international dates (DD/MM).
+# Date display format for CGI interface.  A value of 1 uses US-style
+# dates (MM/DD), a value of 2 uses full YYYY-MM-DD format, and zero
+# for international dates (DD/MM).
 #
 $Conf{CgiDateFormatMMDD} = 1;
 
@@ -1928,8 +2091,8 @@ $Conf{CgiNavBarLinks} = [
         lname => "Documentation",    # actually displays $Lang->{Documentation}
     },
     {
-        link  => "http://backuppc.sourceforge.net/faq",
-        name  => "FAQ",              # displays literal "FAQ"
+        link  => "http://backuppc.wiki.sourceforge.net",
+        name  => "Wiki",              # displays literal "Wiki"
     },
     {
         link  => "http://backuppc.sourceforge.net",
@@ -1961,7 +2124,7 @@ $Conf{CgiHeaders} = '<meta http-equiv="pragma" content="no-cache">';
 # used by configure.pl when you upgrade BackupPC.
 #
 # Example:
-#     $Conf{CgiImageDir} = '/usr/local/apache/htdocs/BackupPC';
+#     $Conf{CgiImageDir} = '/var/www/htdocs/BackupPC';
 #
 $Conf{CgiImageDir} = '';
 
@@ -2035,6 +2198,7 @@ $Conf{CgiUserConfigEdit} = {
         BlackoutPeriods           => 1,
         BackupZeroFilesIsFatal    => 1,
         ClientCharset             => 1,
+        ClientCharsetLegacy       => 1,
         XferMethod                => 1,
         XferLogLevel              => 1,
         SmbShareName              => 1,
@@ -2052,13 +2216,23 @@ $Conf{CgiUserConfigEdit} = {
         RsyncShareName            => 1,
         RsyncdClientPort          => 1,
         RsyncdPasswd              => 1,
+        RsyncdUserName            => 1,
         RsyncdAuthRequired        => 1,
         RsyncCsumCacheVerifyProb  => 1,
         RsyncArgs                 => 1,
+        RsyncArgsExtra            => 1,
         RsyncRestoreArgs          => 1,
         RsyncClientCmd            => 0,
         RsyncClientRestoreCmd     => 0,
         RsyncClientPath           => 0,
+        FtpShareName              => 1,
+        FtpUserName               => 1,
+        FtpPasswd                 => 1,
+        FtpBlockSize              => 1,
+        FtpPort                   => 1,
+        FtpTimeout                => 1,
+        FtpFollowSymlinks         => 1,
+        FtpRestoreEnabled         => 1,
         ArchiveDest               => 1,
         ArchiveComp               => 1,
         ArchivePar                => 1,
