@@ -1,4 +1,4 @@
-#!/bin/perl
+#!/usr/bin/perl
 
 #my %lang;
 
@@ -41,12 +41,16 @@ $Lang{Admin_Options_Page} = <<EOF;
 </ul>
 -->
 EOF
-$Lang{Unable_to_connect_to_BackupPC_server} = "Imposible conectar al servidor BackupPC",
-            "Este script CGI (\$MyURL) no puede conectar al servidor BackupPC"
-          . " en \$Conf{ServerHost} puerto \$Conf{ServerPort}.  El error"
-          . " fu: \$err.",
-            "Quiz el servidor BackupPC no est activo o hay un "
-          . " error de configuracin. Por favor informe a su administrador de sistemas.";
+
+$Lang{Unable_to_connect_to_BackupPC_server} = "Imposible conectar al servidor BackupPC";
+$Lang{Unable_to_connect_to_BackupPC_server_error_message} = <<EOF;
+Este script CGI (\$MyURL) no puede conectar al servidor BackupPC
+en \$Conf{ServerHost} puerto \$Conf{ServerPort}.<br>
+El error fu: \$err.<br>
+Quiz el servidor BackupPC no est activo o hay un
+error de configuracin. Por favor informe a su administrador de sistemas.
+EOF
+
 $Lang{Admin_Start_Server} = <<EOF;
 \${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
 <form action="\$MyURL" method="get">
@@ -155,6 +159,7 @@ Il y a \$hostCntGood hosts tienen copia de seguridad, de un total de :
     <td align="center"> Incrementales Antig (Das) </td>
     <td align="center"> ENG Last Backup (days) </td>
     <td align="center"> Estado </td>
+    <td align="center"> N Xfer errs </td>
     <td align="center"> Ultimo Intento </td></tr>
 \$strGood
 </table>
@@ -174,6 +179,7 @@ Hay \$hostCntNone hosts sin copias de seguridad.
     <td align="center"> Incrementales Antig (Das) </td>
     <td align="center"> ENG Last Backup (days) </td>
     <td align="center"> Estado </td>
+    <td align="center"> N Xfer errs </td>
     <td align="center"> Ultimo Intento </td></tr>
 \$strNone
 </table>
@@ -1383,11 +1389,11 @@ $Lang{CfgEdit_Title_User_URLs} = "User URLs";
 $Lang{CfgEdit_Title_User_Config_Editing} = "User Config Editing";
 $Lang{CfgEdit_Title_Xfer} = "Xfer";
 $Lang{CfgEdit_Title_Xfer_Settings} = "Xfer Settings";
+$Lang{CfgEdit_Title_Ftp_Settings} = "FTP Settings";
 $Lang{CfgEdit_Title_Smb_Settings} = "Smb Settings";
 $Lang{CfgEdit_Title_Tar_Settings} = "Tar Settings";
 $Lang{CfgEdit_Title_Rsync_Settings} = "Rsync Settings";
 $Lang{CfgEdit_Title_Rsyncd_Settings} = "Rsyncd Settings";
-$Lang{CfgEdit_Title_BackupPCd_Settings} = "BackupPCd Settings";
 $Lang{CfgEdit_Title_Archive_Settings} = "Archive Settings";
 $Lang{CfgEdit_Title_Include_Exclude} = "Include/Exclude";
 $Lang{CfgEdit_Title_Smb_Paths_Commands} = "Smb Paths/Commands";
